@@ -38,10 +38,6 @@
 #include "CDuplicateChannelEdit.h"
 #include "CRemoveChannelsEdit.h"
 
-// ---------- does not appear actually under the Edit menu
-#include "CSaveSelectionAsAction.h"
-#include "CSaveAsMultipleFilesAction.h"
-#include "CBurnToCDAction.h"
 
 
 #endif
